@@ -15,7 +15,9 @@
 """
 import unittest
 
+from zope.component.tests import skipIfNoSecurity
 
+@skipIfNoSecurity
 class StandaloneTests(unittest.TestCase):
     def testStandalone(self):
         # See: https://bugs.launchpad.net/zope3/+bug/98401
@@ -28,19 +30,20 @@ class StandaloneTests(unittest.TestCase):
         where = os.path.dirname(os.path.dirname(__file__))
         program = os.path.join(where, 'standalonetests.py')
         process = subprocess.Popen([executable, program],
-                                   stdout=subprocess.PIPE,
-                                   stderr=subprocess.STDOUT,
-                                   stdin=subprocess.PIPE)
+                                stdout=subprocess.PIPE,
+                                stderr=subprocess.STDOUT,
+                                stdin=subprocess.PIPE)
         try:
             pickle.dump(sys.path, process.stdin)
             process.stdin.close()
 
             try:
                 rc = process.wait()
-            except OSError as e:
-                if e.errno != 4: # MacIntel raises apparently unimportant EINTR?
+            except OSError as e: # pragma: no cover
+                # MacIntel raises apparently unimportant EINTR?
+                if e.errno != 4:
                     raise # TODO verify sanity of a pass on EINTR :-/
-            if rc != 0:
+            if rc != 0: # pragma: no cover
                 output = process.stdout.read()
                 if isinstance(output, bytes):
                     output = output.decode()
@@ -50,8 +53,3 @@ class StandaloneTests(unittest.TestCase):
                 self.fail('Output code: %d' % rc)
         finally:
             process.stdout.close()
-
-def test_suite():
-    return unittest.TestSuite((
-        unittest.makeSuite(StandaloneTests),
-    ))
